@@ -1,20 +1,19 @@
 import json
 import requests
 
-from common.configuration.httpClientConfig import HttClientConfig
-from common.dto import LogCreateDto
-from common.dto import LogRequestDto
+from common.configuration.httpClientConfig import HttpClientConfig
+from common.dto.logCreateDto import LogCreateDto
+from common.dto.logRequestDto import LogRequestDto
 from common.enums.logLevel import LogLevel
 from common.enums.platform import Platform
 
-
 with requests.Session() as session:
     session.headers.update({
         'Content-Type': 'application/json',
     })
 
     def init(api_key):
-        response = session.post(f'{HttClientConfig.alertNowURL}/users/sign-in-with-api-key/{api_key}')
+        response = session.post(f'{HttpClientConfig.alertNowURL}/users/sign-in-with-api-key/{api_key}')
         if response.status_code != 200:
             return response
 
@@ -32,6 +31,6 @@ with requests.Session() as session:
 
     def create_log(log_create_dto):
         log_request_dto = LogRequestDto(Platform.PYTHON.value, json.dumps(vars(log_create_dto)))
-        response = session.post(f'{HttClientConfig.alertNowURL}/logs/create',
+        response = session.post(f'{HttpClientConfig.alertNowURL}/logs/create',
                                 data=json.dumps(vars(log_request_dto)))
         return response
